@@ -181,9 +181,7 @@ class FileState:
 
 
 class FileEditor:
-    """File Editor in charge of updating file on disk and memory objects.
-
-    """
+    """File Editor in charge of updating file on disk and memory objects."""
 
     __slots__ = [
         "directory",
@@ -307,7 +305,7 @@ class FileEditor:
                 # export operation.
                 with open(self.fullpath, "rb") as f:
                     content = f.read()
-                self.svnrepo.client.export(
+                self.svnrepo.export(
                     os.path.join(self.svnrepo.remote_url.encode(), self.path),
                     to=self.fullpath,
                     peg_rev=self.editor.revnum,
@@ -444,9 +442,7 @@ class DirEditor:
         self.editor.modified_paths.discard(path)
 
     def open_directory(self, path: str, *args) -> DirEditor:
-        """Updating existing directory.
-
-        """
+        """Updating existing directory."""
         return DirEditor(
             self.directory,
             rootpath=self.rootpath,
@@ -457,9 +453,7 @@ class DirEditor:
         )
 
     def add_directory(self, path: str, *args) -> DirEditor:
-        """Adding a new directory.
-
-        """
+        """Adding a new directory."""
         path_bytes = os.fsencode(path)
 
         os.makedirs(os.path.join(self.rootpath, path_bytes), exist_ok=True)
@@ -477,9 +471,7 @@ class DirEditor:
         )
 
     def open_file(self, path: str, *args) -> FileEditor:
-        """Updating existing file.
-
-        """
+        """Updating existing file."""
         path_bytes = os.fsencode(path)
         self.directory[path_bytes] = from_disk.Content()
         fullpath = os.path.join(self.rootpath, path_bytes)
@@ -492,9 +484,7 @@ class DirEditor:
         )
 
     def add_file(self, path: str, *args) -> FileEditor:
-        """Creating a new file.
-
-        """
+        """Creating a new file."""
         path_bytes = os.fsencode(path)
         self.directory[path_bytes] = from_disk.Content()
         fullpath = os.path.join(self.rootpath, path_bytes)
@@ -508,9 +498,7 @@ class DirEditor:
         )
 
     def change_prop(self, key: str, value: str) -> None:
-        """Change property callback on directory.
-
-        """
+        """Change property callback on directory."""
         if key == properties.PROP_EXTERNALS:
             logger.debug(
                 "Setting '%s' property with value '%s' on path %s",
@@ -520,22 +508,35 @@ class DirEditor:
             )
             self.externals = defaultdict(list)
             if value is not None:
-                # externals are set on that directory path, parse and store them
-                # for later processing in the close method
-                for external in value.split("\n"):
-                    external = external.rstrip("\r")
-                    # skip empty line or comment
-                    if not external or external.startswith("#"):
-                        continue
-                    (
-                        path,
-                        external_url,
-                        revision,
-                        relative_url,
-                    ) = parse_external_definition(
-                        external, os.fsdecode(self.path), self.svnrepo.origin_url
+                try:
+                    # externals are set on that directory path, parse and store them
+                    # for later processing in the close method
+                    for external in value.split("\n"):
+                        external = external.rstrip("\r")
+                        # skip empty line or comment
+                        if not external or external.startswith("#"):
+                            continue
+                        (
+                            path,
+                            external_url,
+                            revision,
+                            relative_url,
+                        ) = parse_external_definition(
+                            external, os.fsdecode(self.path), self.svnrepo.origin_url
+                        )
+                        self.externals[path].append(
+                            (external_url, revision, relative_url)
+                        )
+                except ValueError:
+                    logger.debug(
+                        "Failed to parse external: %s\n"
+                        "Externals defined on path %s will not be processed",
+                        external,
+                        self.path,
                     )
-                    self.externals[path].append((external_url, revision, relative_url))
+                    # as the official subversion client, do not process externals in case
+                    # of parsing error
+                    self.externals = {}
 
             if not self.externals:
                 # externals might have been unset on that directory path,
@@ -547,9 +548,7 @@ class DirEditor:
                 self.dir_states[self.path].externals = {}
 
     def delete_entry(self, path: str, revision: int) -> None:
-        """Remove a path.
-
-        """
+        """Remove a path."""
         path_bytes = os.fsencode(path)
         if path_bytes not in self.editor.external_paths:
             fullpath = os.path.join(self.rootpath, path_bytes)
@@ -682,13 +681,11 @@ class DirEditor:
                         and not self.svnrepo.has_relative_externals
                     ):
                         url = url.replace(origin_url, self.svnrepo.remote_url)
-                    logger.debug(
-                        "svn export --ignore-keywords %s%s",
+                    self.svnrepo.export(
                         url,
-                        f"@{revision}" if revision else "",
-                    )
-                    self.svnrepo.client.export(
-                        url, to=temp_path, peg_rev=revision, ignore_keywords=True,
+                        to=temp_path,
+                        peg_rev=revision,
+                        ignore_keywords=True,
                     )
                     self.editor.externals_cache[external] = temp_path
 
@@ -743,7 +740,11 @@ class DirEditor:
                 # copy_tree needs sub-directories to exist in destination
                 for root, dirs, files in os.walk(temp_path):
                     for dir in dirs:
-                        subdir = os.path.join(root, dir).replace(temp_path + b"/", b"")
+                        temp_dir_fullpath = os.path.join(root, dir)
+                        if os.path.islink(temp_dir_fullpath):
+                            # do not create folder if it's a link or copy_tree will fail
+                            continue
+                        subdir = temp_dir_fullpath.replace(temp_path + b"/", b"")
                         self.add_directory(
                             os.fsdecode(os.path.join(dest_fullpath, subdir))
                         )
@@ -840,10 +841,10 @@ class DirEditor:
 
 class Editor:
     """Editor in charge of replaying svn events and computing objects
-       along.
+    along.
 
-       This implementation accounts for empty folder during hash
-       computations.
+    This implementation accounts for empty folder during hash
+    computations.
 
     """
 
@@ -891,8 +892,7 @@ class Editor:
 
 
 class Replay:
-    """Replay class.
-    """
+    """Replay class."""
 
     def __init__(
         self,
@@ -990,9 +990,7 @@ class Replay:
     help="Indicates whether to cleanup disk when done or not.",
 )
 def main(local_url, svn_url, revision_start, revision_end, debug, cleanup):
-    """Script to present how to use Replay class.
-
-    """
+    """Script to present how to use Replay class."""
     conn = RemoteAccess(svn_url.encode("utf-8"), auth=Auth([get_username_provider()]))
 
     os.makedirs(local_url, exist_ok=True)
