@@ -8,14 +8,13 @@ representations including the hash tree/content computations per svn
 commit.
 
 """
-
 import logging
 import os
 import shutil
 import tempfile
 from typing import Dict, Iterator, List, Optional, Tuple, Union
 
-from subvertpy import SubversionException, client, properties
+from subvertpy import SubversionException, client, properties, wc
 from subvertpy.ra import Auth, RemoteAccess, get_username_provider
 
 from swh.model.from_disk import Directory as DirectoryFromDisk
@@ -28,12 +27,12 @@ from swh.model.model import (
 )
 
 from . import converters, replay
+from .svn_retry import svn_retry
 from .utils import is_recursive_external, parse_external_definition
 
 # When log message contains empty data
 DEFAULT_AUTHOR_MESSAGE = ""
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -61,9 +60,9 @@ class SvnRepo:
 
         auth = Auth([get_username_provider()])
         # one connection for log iteration
-        self.conn_log = RemoteAccess(self.remote_url, auth=auth)
+        self.conn_log = self.remote_access(auth)
         # another for replay
-        self.conn = RemoteAccess(self.remote_url, auth=auth)
+        self.conn = self.remote_access(auth)
         # one client for update operation
         self.client = client.Client(auth=auth)
 
@@ -85,8 +84,7 @@ class SvnRepo:
 
         # compute root directory path from the remote repository URL, required to
         # properly load the sub-tree of a repository mounted from a dump file
-        info = self.client.info(origin_url.rstrip("/"))
-        repos_root_url = next(iter(info.values())).repos_root_url
+        repos_root_url = self.info(origin_url).repos_root_url
         self.root_directory = origin_url.replace(repos_root_url, "", 1)
 
     def __str__(self):
@@ -100,15 +98,11 @@ class SvnRepo:
         )
 
     def head_revision(self) -> int:
-        """Retrieve current head revision.
-
-        """
+        """Retrieve current head revision."""
         return self.conn.get_latest_revnum()
 
     def initial_revision(self) -> int:
-        """Retrieve the initial revision from which the remote url appeared.
-
-        """
+        """Retrieve the initial revision from which the remote url appeared."""
         return 1
 
     def convert_commit_message(self, msg: Union[str, bytes]) -> bytes:
@@ -213,6 +207,136 @@ class SvnRepo:
         ):
             yield self.__to_entry(log_entry)
 
+    @svn_retry()
+    def remote_access(self, auth: Auth) -> RemoteAccess:
+        """Simple wrapper around subvertpy.ra.RemoteAccess creation
+        enabling to retry the operation if a network error occurs."""
+        return RemoteAccess(self.remote_url, auth=auth)
+
+    @svn_retry()
+    def info(self, origin_url: str):
+        """Simple wrapper around subvertpy.client.Client.info enabling to retry
+        the command if a network error occurs."""
+        info = self.client.info(origin_url.rstrip("/"))
+        return next(iter(info.values()))
+
+    @svn_retry()
+    def export(
+        self,
+        url: str,
+        to: str,
+        rev: Optional[int] = None,
+        peg_rev: Optional[int] = None,
+        recurse: bool = True,
+        ignore_externals: bool = False,
+        overwrite: bool = False,
+        ignore_keywords: bool = False,
+    ) -> int:
+        """Simple wrapper around subvertpy.client.Client.export enabling to retry
+        the command if a network error occurs.
+
+        See documentation of svn_client_export5 function from subversion C API
+        to get details about parameters.
+        """
+        # remove export path as command can be retried
+        if os.path.isfile(to) or os.path.islink(to):
+            os.remove(to)
+        elif os.path.isdir(to):
+            shutil.rmtree(to)
+        options = []
+        if rev is not None:
+            options.append(f"-r {rev}")
+        if recurse:
+            options.append("--depth infinity")
+        if ignore_externals:
+            options.append("--ignore-externals")
+        if overwrite:
+            options.append("--force")
+        if ignore_keywords:
+            options.append("--ignore-keywords")
+        logger.debug(
+            "svn export %s %s%s %s",
+            " ".join(options),
+            url,
+            f"@{peg_rev}" if peg_rev else "",
+            to,
+        )
+        return self.client.export(
+            url,
+            to=to,
+            rev=rev,
+            peg_rev=peg_rev,
+            recurse=recurse,
+            ignore_externals=ignore_externals,
+            overwrite=overwrite,
+            ignore_keywords=ignore_keywords,
+        )
+
+    @svn_retry()
+    def checkout(
+        self,
+        url: str,
+        path: str,
+        rev: Optional[int] = None,
+        peg_rev: Optional[int] = None,
+        recurse: bool = True,
+        ignore_externals: bool = False,
+        allow_unver_obstructions: bool = False,
+    ) -> int:
+        """Simple wrapper around subvertpy.client.Client.checkout enabling to retry
+        the command if a network error occurs.
+
+        See documentation of svn_client_checkout3 function from subversion C API
+        to get details about parameters.
+        """
+        if os.path.isdir(os.path.join(path, ".svn")):
+            # cleanup checkout path as command can be retried and svn working copy might
+            # be locked
+            wc.cleanup(path)
+        elif os.path.isdir(path):
+            # recursively remove checkout path otherwise if it is not a svn working copy
+            shutil.rmtree(path)
+        options = []
+        if rev is not None:
+            options.append(f"-r {rev}")
+        if recurse:
+            options.append("--depth infinity")
+        if ignore_externals:
+            options.append("--ignore-externals")
+        logger.debug(
+            "svn checkout %s %s%s %s",
+            " ".join(options),
+            self.remote_url,
+            f"@{peg_rev}" if peg_rev else "",
+            path,
+        )
+        return self.client.checkout(
+            url,
+            path=path,
+            rev=rev,
+            peg_rev=peg_rev,
+            recurse=recurse,
+            ignore_externals=ignore_externals,
+            allow_unver_obstructions=allow_unver_obstructions,
+        )
+
+    @svn_retry()
+    def propget(
+        self,
+        name: str,
+        target: str,
+        peg_rev: Optional[int],
+        rev: Optional[int] = None,
+        recurse: bool = False,
+    ):
+        """Simple wrapper around subvertpy.client.Client.propget enabling to retry
+        the command if a network error occurs.
+
+        See documentation of svn_client_propget5 function from subversion C API
+        to get details about parameters.
+        """
+        return self.client.propget(name, target, peg_rev, rev, recurse)
+
     def export_temporary(self, revision: int) -> Tuple[str, bytes]:
         """Export the repository to a given revision in a temporary location. This is up
         to the caller of this function to clean up the temporary location when done (cf.
@@ -248,16 +372,12 @@ class SvnRepo:
             with tempfile.TemporaryDirectory(
                 dir=self.local_dirname, prefix=f"checkout-revision-{revision}."
             ) as co_dirname:
-                logger.debug(
-                    "svn checkout --ignore-externals %s@%s", self.remote_url, revision,
-                )
-                self.client.checkout(
+
+                self.checkout(
                     self.remote_url, co_dirname, revision, ignore_externals=True
                 )
                 # get all svn:externals properties recursively
-                externals = self.client.propget(
-                    "svn:externals", co_dirname, None, None, True
-                )
+                externals = self.propget("svn:externals", co_dirname, None, None, True)
                 self.has_relative_externals = False
                 self.has_recursive_externals = False
                 for path, external_defs in externals.items():
@@ -278,7 +398,10 @@ class SvnRepo:
                         )
 
                         if is_recursive_external(
-                            self.origin_url, path, external_path, external_url,
+                            self.origin_url,
+                            path,
+                            external_path,
+                            external_url,
                         ):
                             self.has_recursive_externals = True
                             url = self.remote_url
@@ -291,10 +414,8 @@ class SvnRepo:
 
         try:
             url = url.rstrip("/")
-            logger.debug(
-                "svn export --ignore-keywords %s@%s", url, revision,
-            )
-            self.client.export(
+
+            self.export(
                 url,
                 to=local_url,
                 rev=revision,
